<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.0" language="nl">
<context>
    <name>ChainsProxyPage</name>
    <message>
        <source>Application Proxy</source>
        <translation>Programmaproxy</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Soort proxy</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP-adres</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Vereist</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Poort</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Gebruikersnaam</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>Optioneel</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Wachtwoord</translation>
    </message>
    <message>
        <source>Check &quot;Use a proxy&quot; in application context menu in Launcher after configured</source>
        <translation>Kruis na het instellen de optie ‘Proxy gebruiken’ aan in het rechtermuisknopmenu van de programmastarter</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Annuleren</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Opslaan</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Ongeldig ip-adres</translation>
    </message>
    <message>
        <source>Invalid port</source>
        <translation>Ongeldige poort</translation>
    </message>
</context>
<context>
    <name>ConnectionEditPage</name>
    <message>
        <source>Disconnect</source>
        <comment>button</comment>
        <translation>Verbinding verbreken</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Verwijderen</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Annuleren</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Opslaan</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Bezig met verbinden</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Verbinding verbreken</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation>Weet je zeker dat je deze configuratie wilt verwijderen?</translation>
    </message>
    <message>
        <source>Wired Connection %1</source>
        <translation>Bekabelde verbinding %1</translation>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>Hotspot</translation>
    </message>
    <message>
        <source>Wireless Connection %1</source>
        <translation>Draadloze verbinding %1</translation>
    </message>
    <message>
        <source>PPPoE Connection %1</source>
        <translation>PPPoE-verbinding %1</translation>
    </message>
</context>
<context>
    <name>ConnectionVpnEditPage</name>
    <message>
        <source>New VPN</source>
        <translation>Nieuwe vpn</translation>
    </message>
    <message>
        <source>VPN Type</source>
        <translation>Soort vpn</translation>
    </message>
    <message>
        <source>L2TP</source>
        <translation>L2TP</translation>
    </message>
    <message>
        <source>PPTP</source>
        <translation>PPTP</translation>
    </message>
    <message>
        <source>OpenVPN</source>
        <translation>OpenVPN</translation>
    </message>
    <message>
        <source>OpenConnect</source>
        <translation>OpenConnect</translation>
    </message>
    <message>
        <source>StrongSwan</source>
        <translation>StrongSwan</translation>
    </message>
    <message>
        <source>VPNC</source>
        <translation>VPNC</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>Exporteren</translation>
    </message>
    <message>
        <source>VPN L2TP %1</source>
        <translation>VPN L2TP %1</translation>
    </message>
    <message>
        <source>VPN PPTP %1</source>
        <translation>VPN PPTP %1</translation>
    </message>
    <message>
        <source>VPN VPNC %1</source>
        <translation>VPN VPNC %1</translation>
    </message>
    <message>
        <source>VPN OpenVPN %1</source>
        <translation>VPN OpenVPN %1</translation>
    </message>
    <message>
        <source>VPN StrongSwan %1</source>
        <translation>VPN StrongSwan %1</translation>
    </message>
    <message>
        <source>VPN OpenConnect %1</source>
        <translation>VPN OpenConnect %1</translation>
    </message>
</context>
<context>
    <name>DCCNetworkModule</name>
    <message>
        <source>Network</source>
        <translation>Netwerk</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation>Programmaproxy</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>Persoonlijke hotspot</translation>
    </message>
    <message>
        <source>Network Details</source>
        <translation>Netwerkinformatie</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>Systeemproxy</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Bekabeld netwerk</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Draadloos netwerk</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation>Vliegtuigstand</translation>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation>Bekabelde netwerkadapter</translation>
        <extra-contents_path>/network/Wired Network</extra-contents_path>
        <extra-child_page>Wired Network</extra-child_page>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>Netwerkverbinding toevoegen</translation>
        <extra-contents_path>/network/Wired Network/addWiredConnection</extra-contents_path>
        <extra-child_page>Wired Network</extra-child_page>
    </message>
    <message>
        <source>Wireless Network Adapter</source>
        <translation>Draadloze netwerkadapter</translation>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
        <extra-child_page>Wireless Network</extra-child_page>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>Verbinden met verborgen netwerk</translation>
        <extra-contents_path>/network/Wireless Network/Connect to hidden network</extra-contents_path>
        <extra-child_page>Wireless Network</extra-child_page>
    </message>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
        <extra-contents_path>/network/DSL</extra-contents_path>
        <extra-child_page_hide>DSL</extra-child_page_hide>
    </message>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>PPPoE-verbinding opzetten</translation>
        <extra-contents_path>/network/DSL/Create PPPoE Connection</extra-contents_path>
        <extra-child_page>DSL</extra-child_page>
    </message>
    <message>
        <source>VPN Status</source>
        <translation>VPN-status</translation>
        <extra-contents_path>/network/VPN</extra-contents_path>
        <extra-child_page>VPN</extra-child_page>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>VPN toevoegen</translation>
        <extra-contents_path>/network/VPN/Create VPN</extra-contents_path>
        <extra-child_page>VPN</extra-child_page>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>VPN importeren</translation>
        <extra-contents_path>/network/VPN/Import VPN</extra-contents_path>
        <extra-child_page>VPN</extra-child_page>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Soort proxy</translation>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>Configuratie-url</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP-adres</translation>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
        <extra-child_page>Application Proxy</extra-child_page>
    </message>
    <message>
        <source>Port</source>
        <translation>Poort</translation>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
        <extra-child_page>Application Proxy</extra-child_page>
    </message>
    <message>
        <source>Username</source>
        <translation>Gebruikersnaam</translation>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
        <extra-child_page>Application Proxy</extra-child_page>
    </message>
    <message>
        <source>Password</source>
        <translation>Wachtwoord</translation>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
        <extra-child_page>Application Proxy</extra-child_page>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>Hotspot</translation>
        <extra-contents_path>/network/Personal Hotspot</extra-contents_path>
        <extra-child_page>Personal Hotspot</extra-child_page>
    </message>
    <message>
        <source>Create Hotspot</source>
        <translation>Hotspot opzetten</translation>
        <extra-contents_path>/network/Personal Hotspot/Create Hotspot</extra-contents_path>
        <extra-child_page>Personal Hotspot</extra-child_page>
    </message>
    <message>
        <source>Interface</source>
        <translation>Uiterlijk</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Band</source>
        <translation>Band</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>Primaire dns-server</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Netmasker</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Voorvoegsel</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Speed</source>
        <translation>Snelheid</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
</context>
<context>
    <name>dccV20::network::AirplaneModepage</name>
    <message>
        <source>Airplane Mode</source>
        <translation>Vliegtuigstand</translation>
    </message>
    <message>
        <source>Enabling the airplane mode turns off wireless network, personal hotspot and Bluetooth</source>
        <translation>Door de vliegtuigstand worden draadloos internet, bluetooth en uw persoonlijke hotspot uitgeschakeld</translation>
    </message>
</context>
<context>
    <name>DNSSection</name>
    <message>
        <source>DNS</source>
        <translation>DNS</translation>
    </message>
    <message>
        <source>Invalid DNS address</source>
        <translation>Ongeldig dns-adres</translation>
    </message>
</context>
<context>
    <name>EthernetSection</name>
    <message>
        <source>Ethernet</source>
        <translation>Ethernet</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>Niet verbonden</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>MAC-adres van apparaat</translation>
    </message>
    <message>
        <source>Cloned MAC Addr</source>
        <translation>Gekloond mac-adres</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>MTU aanpassen</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
</context>
<context>
    <name>GenericHotspotSection</name>
    <message>
        <source>General</source>
        <translation>Algemeen</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Naam</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Vereist</translation>
    </message>
</context>
<context>
    <name>GenericSection</name>
    <message>
        <source>General</source>
        <translation>Algemeen</translation>
    </message>
    <message>
        <source>The name already exists</source>
        <translation>Deze naam is al in gebruik</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Naam</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Vereist</translation>
    </message>
    <message>
        <source>Auto Connect</source>
        <translation>Automatisch verbinden</translation>
    </message>
</context>
<context>
    <name>HotspotDeviceWidget</name>
    <message>
        <source>Hotspot</source>
        <translation>Hotspot</translation>
    </message>
    <message>
        <source>Add Settings</source>
        <translation>Instellingen toevoegen</translation>
    </message>
</context>
<context>
    <name>HotspotPage</name>
    <message>
        <source>Create Hotspot</source>
        <translation>Hotspot opzetten</translation>
    </message>
</context>
<context>
    <name>IPInputSection</name>
    <message>
        <source>IP Address</source>
        <translation>IP-adres</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Vereist</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
</context>
<context>
    <name>IPV4InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation>Dubbel ip-adres</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Ongeldig ip-adres</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation>Ongeldig netmasker</translation>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation>Er is slechts één gateway toegestaan</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Ongeldige gateway</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Netmasker</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Vereist</translation>
    </message>
</context>
<context>
    <name>IPV6InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation>Dubbel ip-adres</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Ongeldig ip-adres</translation>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation>Er is slechts één gateway toegestaan</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Ongeldige gateway</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Voorvoegsel</translation>
    </message>
</context>
<context>
    <name>IpvxSection</name>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automatisch</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Handmatig</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Negeren</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP-adres</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Vereist</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Only applied in corresponding resources</source>
        <translation>Alleen van toepassing op overeenkomstige bronnen</translation>
    </message>
    <message>
        <source>Method</source>
        <translation>Methode</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Netmasker</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Voorvoegsel</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Ongeldig ip-adres</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation>Ongeldig netmasker</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Ongeldige gateway</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Netwerk</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP-conflict</translation>
    </message>
</context>
<context>
    <name>MultiIpvxSection</name>
    <message>
        <source>Method</source>
        <translation>Methode</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automatisch</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Handmatig</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Negeren</translation>
    </message>
</context>
<context>
    <name>NetworkDetailPage</name>
    <message>
        <source>Network Details</source>
        <translation>Netwerkinformatie</translation>
    </message>
</context>
<context>
    <name>NetworkModuleWidget</name>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>Systeemproxy</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation>Programmaproxy</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation>Vliegtuigstand</translation>
        <extra-contents_path>/network/Airplane</extra-contents_path>
    </message>
    <message>
        <source>Network Details</source>
        <translation>Netwerkinformatie</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Netwerk</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP-conflict</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Uitgeschakeld</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Handmatig</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automatisch</translation>
    </message>
    <message>
        <source>Configure by Network Manager</source>
        <translation>Ingesteld door NetworkManager</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>Persoonlijke hotspot</translation>
    </message>
</context>
<context>
    <name>PPPOESection</name>
    <message>
        <source>PPPoE</source>
        <translation>PPPoE</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Gebruikersnaam</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Vereist</translation>
    </message>
    <message>
        <source>Service</source>
        <translation>Dienst</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Wachtwoord</translation>
    </message>
</context>
<context>
    <name>PPPSection</name>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>EAP-authenticatie weigeren</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>PAP-authenticatie weigeren</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>CHAP-authenticatie weigeren</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>MSCHAP-authenticatie weigeren</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>MSCHAPv2-authenticatie weigeren</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>Geen BSD-gegevenscompressie</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Geen deflate-gegevenscompressie</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>Geen tcp-kopcompressie</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>Geen protocolveldcompressie</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>Geen adres-/controlecompressie</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>PPP-echopakketten versturen</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>MPPE gebruiken</translation>
    </message>
    <message>
        <source>128-bit MPPE</source>
        <translation>128-bit MPPE</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>Stateful MPPE</translation>
    </message>
</context>
<context>
    <name>PppoePage</name>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>PPPoE-verbinding opzetten</translation>
    </message>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
</context>
<context>
    <name>ProxyPage</name>
    <message>
        <source>System Proxy</source>
        <translation>Systeemproxy</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Annuleren</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Opslaan</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Soort proxy</translation>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
        <extra-child_page>System Proxy</extra-child_page>
    </message>
    <message>
        <source>Manual</source>
        <translation>Handmatig</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automatisch</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>Optioneel</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Poort</translation>
    </message>
    <message>
        <source>HTTP Proxy</source>
        <translation>HTTP-proxy</translation>
    </message>
    <message>
        <source>HTTPS Proxy</source>
        <translation>HTTPS-proxy</translation>
    </message>
    <message>
        <source>FTP Proxy</source>
        <translation>FTP-proxy</translation>
    </message>
    <message>
        <source>SOCKS Proxy</source>
        <translation>SOCKS-proxy</translation>
    </message>
    <message>
        <source>Ignore the proxy configurations for the above hosts and domains</source>
        <translation>Negeer de proxy-instellingen voor bovenstaande hosts en domeinen</translation>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>Configuratie-url</translation>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
        <extra-child_page>System Proxy</extra-child_page>
    </message>
</context>
<context>
    <name>Secret8021xSection</name>
    <message>
        <source>Security</source>
        <translation>Beveiliging</translation>
    </message>
    <message>
        <source>TLS</source>
        <translation>TLS</translation>
    </message>
    <message>
        <source>MD5</source>
        <translation>MD5</translation>
    </message>
    <message>
        <source>LEAP</source>
        <translation>LEAP</translation>
    </message>
    <message>
        <source>FAST</source>
        <translation>FAST</translation>
    </message>
    <message>
        <source>Tunneled TLS</source>
        <translation>Tunneled TLS</translation>
    </message>
    <message>
        <source>Protected EAP</source>
        <translation>Beschermde EAP</translation>
    </message>
    <message>
        <source>Save password for this user</source>
        <translation>Wachtwoord opslaan voor gebruiker</translation>
    </message>
    <message>
        <source>Save password for all users</source>
        <translation>Wachtwoord opslaan voor alle gebruikers</translation>
    </message>
    <message>
        <source>Ask me always</source>
        <translation>Altijd vragen</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Uitgeschakeld</translation>
    </message>
    <message>
        <source>Anonymous</source>
        <translation>Annoniem</translation>
    </message>
    <message>
        <source>Authenticated</source>
        <translation>Geverifieerd</translation>
    </message>
    <message>
        <source>Both</source>
        <translation>Beide</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>Automatisch</translation>
    </message>
    <message>
        <source>Version 0</source>
        <translation>Versie 0</translation>
    </message>
    <message>
        <source>Version 1</source>
        <translation>Versie 1</translation>
    </message>
    <message>
        <source>EAP Auth</source>
        <translation>EAP-authenticatie</translation>
    </message>
    <message>
        <source>Identity</source>
        <translation>Identiteit</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Vereist</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Pwd-opties</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Privésleutel</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA-certificaat</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Gebruikerscertificaat</translation>
    </message>
    <message>
        <source>Anonymous ID</source>
        <translation>Anonieme identiteit</translation>
    </message>
    <message>
        <source>Provisioning</source>
        <translation>Toelevering</translation>
    </message>
    <message>
        <source>PAC file</source>
        <translation>PAC-bestand</translation>
    </message>
    <message>
        <source>Inner Auth</source>
        <translation>Inner-authenticatie</translation>
    </message>
    <message>
        <source>PEAP Version</source>
        <translation>PEAP-versie</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Privéwachtwoord</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Wachtwoord</translation>
    </message>
</context>
<context>
    <name>SecretHotspotSection</name>
    <message>
        <source>Invalid password</source>
        <translation>Ongeldig wachtwoord</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Geen</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 persoonlijk</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation>WPA3 persoonlijk</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Beveiliging</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Vereist</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>Sleutel</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Wachtwoord</translation>
    </message>
</context>
<context>
    <name>SecretWiredSection</name>
    <message>
        <source>Security Required</source>
        <translation>Beveiliging vereist</translation>
    </message>
</context>
<context>
    <name>SecretWirelessSection</name>
    <message>
        <source>Invalid password</source>
        <translation>Ongeldig wachtwoord</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Geen</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 persoonlijk</translation>
    </message>
    <message>
        <source>WPA/WPA2 Enterprise</source>
        <translation>WPA/WPA2 enterprise</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation>WPA3 persoonlijk</translation>
    </message>
    <message>
        <source>Shared key</source>
        <translation>Gedeelde sleutel</translation>
    </message>
    <message>
        <source>Open system</source>
        <translation>Open systeem</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Beveiliging</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Vereist</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>Verificatie</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>Sleutel</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Wachtwoord</translation>
    </message>
</context>
<context>
    <name>VpnAdvOpenVPNSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>Geavanceerde vpn</translation>
    </message>
    <message>
        <source>Customize Gateway Port</source>
        <translation>Gatewaypoort aanpassen</translation>
    </message>
    <message>
        <source>Gateway Port</source>
        <translation>Gatewaypoort</translation>
    </message>
    <message>
        <source>Customize Renegotiation Interval</source>
        <translation>Aangepaste heronderhandelingstussenpoos gebruiken</translation>
    </message>
    <message>
        <source>Renegotiation Interval</source>
        <translation>Heronderhandelingstussenpoos</translation>
    </message>
    <message>
        <source>Use LZO Data Compression</source>
        <translation>LZO-gegevenscompressie gebruiken</translation>
    </message>
    <message>
        <source>Use TCP Connection</source>
        <translation>TCP-verbinding gebruiken</translation>
    </message>
    <message>
        <source>Use TAP Device</source>
        <translation>TAP-apparaat gebruiken</translation>
    </message>
    <message>
        <source>Customize Tunnel MTU</source>
        <translation>Aangepaste tunnel-mtu gebruiken</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
    <message>
        <source>Customize UDP Fragment Size</source>
        <translation>Aangepaste UDP-fragmentgrootte gebruiken</translation>
    </message>
    <message>
        <source>UDP Fragment Size</source>
        <translation>UDP-fragmentgrootte</translation>
    </message>
    <message>
        <source>Restrict Tunnel TCP MSS</source>
        <translation>TCP MSS-tunnel inperken</translation>
    </message>
    <message>
        <source>Randomize Remote Hosts</source>
        <translation>Willekeurige hosts op afstand</translation>
    </message>
</context>
<context>
    <name>VpnAdvVPNCSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>Geavanceerde vpn</translation>
    </message>
    <message>
        <source>Cisco (default)</source>
        <translation>Cisco (standaard)</translation>
    </message>
    <message>
        <source>Netscreen</source>
        <translation>Netscreen</translation>
    </message>
    <message>
        <source>Secure (default)</source>
        <translation>Veilig (standaard)</translation>
    </message>
    <message>
        <source>Weak</source>
        <translation>Zwak</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Geen</translation>
    </message>
    <message>
        <source>NAT-T When Available (default)</source>
        <translation>NAT-T indien beschikbaar (standaard)</translation>
    </message>
    <message>
        <source>NAT-T Always</source>
        <translation>Altijd NAT-T</translation>
    </message>
    <message>
        <source>Cisco UDP</source>
        <translation>Cisco UDP</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Uitgeschakeld</translation>
    </message>
    <message>
        <source>DH Group 1</source>
        <translation>DH Group 1</translation>
    </message>
    <message>
        <source>DH Group 2 (default)</source>
        <translation>DH Group 2 (standaard)</translation>
    </message>
    <message>
        <source>DH Group 5</source>
        <translation>DH Group 5</translation>
    </message>
    <message>
        <source>Server (default)</source>
        <translation>Server (standaard)</translation>
    </message>
    <message>
        <source>DH Group 2</source>
        <translation>DH Group 2</translation>
    </message>
    <message>
        <source>Domain</source>
        <translation>Domein</translation>
    </message>
    <message>
        <source>Vendor</source>
        <translation>Leverancier</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versie</translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation>Versleuteling</translation>
    </message>
    <message>
        <source>NAT Traversal Mode</source>
        <translation>NAT-traversalmodus</translation>
    </message>
    <message>
        <source>IKE DH Group</source>
        <translation>IKE DH Group</translation>
    </message>
    <message>
        <source>Forward Secrecy</source>
        <translation>Forward Secrecy</translation>
    </message>
    <message>
        <source>Local Port</source>
        <translation>Lokale poort</translation>
    </message>
    <message>
        <source>Disable Dead Peer Detection</source>
        <translation>Inactieve peerdetectie uitschakelen</translation>
    </message>
</context>
<context>
    <name>VpnIpsecSection</name>
    <message>
        <source>VPN IPsec</source>
        <translation>VPN IPsec</translation>
    </message>
    <message>
        <source>Enable IPsec</source>
        <translation>IPsec inschakelen</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>Groepsnaam</translation>
    </message>
    <message>
        <source>Group ID</source>
        <translation>Groepsidentiteit</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>Vooraf gedeelde sleutel</translation>
    </message>
    <message>
        <source>Phase1 Algorithms</source>
        <translation>Fase1-algoritme</translation>
    </message>
    <message>
        <source>Phase2 Algorithms</source>
        <translation>Fase2-algoritme</translation>
    </message>
</context>
<context>
    <name>VpnOpenConnectSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Ongeldige gateway</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Vereist</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA-certificaat</translation>
    </message>
    <message>
        <source>Proxy</source>
        <translation>Proxy</translation>
    </message>
    <message>
        <source>Allow Cisco Secure Desktop Trojan</source>
        <translation>Cisco Secure Desktop Trojan toestaan</translation>
    </message>
    <message>
        <source>CSD Script</source>
        <translation>CSD-script</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Gebruikerscertificaat</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Privésleutel</translation>
    </message>
    <message>
        <source>Use FSID for Key Passphrase</source>
        <translation>FSID gebruiken bij wachtwoordsleutel</translation>
    </message>
</context>
<context>
    <name>VpnOpenVPNSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Ongeldige gateway</translation>
    </message>
    <message>
        <source>Certificates (TLS)</source>
        <translation>Certificaten (TLS)</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Wachtwoord</translation>
    </message>
    <message>
        <source>Certificates with Password (TLS)</source>
        <translation>Certificaten met wachtwoord (TLS)</translation>
    </message>
    <message>
        <source>Static Key</source>
        <translation>Vaste sleutel</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Opgeslagen</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Vragen</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Niet vereist</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Vereist</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>Soort authenticatie</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA-certificaat</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Gebruikerscertificaat</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Privésleutel</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Pwd-opties</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Privéwachtwoord</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Gebruikersnaam</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>Sleutelrichting aanpassen</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>Sleutelrichting</translation>
    </message>
    <message>
        <source>Remote IP</source>
        <translation>Extern ip-adres</translation>
    </message>
    <message>
        <source>Local IP</source>
        <translation>Lokaal ip-adres</translation>
    </message>
</context>
<context>
    <name>VpnPPPSection</name>
    <message>
        <source>VPN PPP</source>
        <translation>VPN PPP</translation>
    </message>
    <message>
        <source>All Available (default)</source>
        <translation>Allen beschikbaar (standaard)</translation>
    </message>
    <message>
        <source>40-bit (less secure)</source>
        <translation>40-bit (minder veilig)</translation>
    </message>
    <message>
        <source>128-bit (most secure)</source>
        <translation>128-bit (veiligst)</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>EAP-authenticatie weigeren</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>PAP-authenticatie weigeren</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>CHAP-authenticatie weigeren</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>MSCHAP-authenticatie weigeren</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>MSCHAPv2-authenticatie weigeren</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>Geen BSD-gegevenscompressie</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Geen deflate-gegevenscompressie</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>Geen tcp-kopcompressie</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>Geen protocolveldcompressie</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>Geen adres-/controlecompressie</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>PPP-echopakketten versturen</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>MPPE gebruiken</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Beveiliging</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>Stateful MPPE</translation>
    </message>
</context>
<context>
    <name>VpnPage</name>
    <message>
        <source>VPN Status</source>
        <translation>VPN-status</translation>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>VPN toevoegen</translation>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>VPN importeren</translation>
    </message>
    <message>
        <source>Import Error</source>
        <translation>Importfout</translation>
    </message>
    <message>
        <source>File error</source>
        <translation>Bestandsfout</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Oké</translation>
    </message>
</context>
<context>
    <name>VpnProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>VPN-proxy</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Niet vereist</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>SOCKS</source>
        <translation>SOCKS</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Soort proxy</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>Server-ip</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Vereist</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Poort</translation>
    </message>
    <message>
        <source>Retry Indefinitely When Failed</source>
        <translation>Blijven proberen na mislukken</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Gebruikersnaam</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Wachtwoord</translation>
    </message>
</context>
<context>
    <name>VpnSSTPSection</name>
    <message>
        <source>CA File</source>
        <translation>CA-bestand</translation>
    </message>
    <message>
        <source>Ignore Certificate Warnings</source>
        <translation>Certificaatwaarschuwingen negeren</translation>
    </message>
    <message>
        <source>Use TLS Hostname Extensions</source>
        <translation>TLS-hostnaamextensies gebruiken</translation>
    </message>
</context>
<context>
    <name>VpnSecOpenVPNSection</name>
    <message>
        <source>VPN Security</source>
        <translation>VPN-beveiliging</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Standaard</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Geen</translation>
    </message>
    <message>
        <source>Cipher</source>
        <translation>Vercijfering</translation>
    </message>
    <message>
        <source>HMAC Auth</source>
        <translation>HMAC Auth</translation>
    </message>
</context>
<context>
    <name>VpnSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Ongeldige gateway</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Opgeslagen</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Vragen</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Niet vereist</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Vereist</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Gebruikersnaam</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Pwd-opties</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Wachtwoord</translation>
    </message>
    <message>
        <source>NT Domain</source>
        <translation>NT-domein</translation>
    </message>
</context>
<context>
    <name>VpnSstpProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>VPN-proxy</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>Server-ip</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Poort</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Gebruikersnaam</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Wachtwoord</translation>
    </message>
</context>
<context>
    <name>VpnStrongSwanSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Ongeldige gateway</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Privésleutel</translation>
    </message>
    <message>
        <source>SSH Agent</source>
        <translation>SSH-agent</translation>
    </message>
    <message>
        <source>Smart Card</source>
        <translation>Smartcard</translation>
    </message>
    <message>
        <source>EAP</source>
        <translation>EAP</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>Vooraf gedeelde sleutel</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Vereist</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA-certificaat</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>Soort authenticatie</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Gebruikerscertificaat</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Gebruikersnaam</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Wachtwoord</translation>
    </message>
    <message>
        <source>Request an Inner IP Address</source>
        <translation>Intern ip-adres opvragen</translation>
    </message>
    <message>
        <source>Enforce UDP Encapsulation</source>
        <translation>UDP-inkapseling afdwingen</translation>
    </message>
    <message>
        <source>Use IP Compression</source>
        <translation>IP-compressie gebruiken</translation>
    </message>
    <message>
        <source>Enable Custom Cipher Proposals</source>
        <translation>Aangepaste vercijferingsvoorstellen gebruiken</translation>
    </message>
    <message>
        <source>IKE</source>
        <translation>IKE</translation>
    </message>
    <message>
        <source>ESP</source>
        <translation>ESP</translation>
    </message>
</context>
<context>
    <name>VpnTLSSection</name>
    <message>
        <source>VPN TLS Authentication</source>
        <translation>VPN TLS-authenticatie</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Standaard</translation>
    </message>
    <message>
        <source>Client</source>
        <translation>Client</translation>
    </message>
    <message>
        <source>Server</source>
        <translation>Server</translation>
    </message>
    <message>
        <source>Subject Match</source>
        <translation>Onderwerpovereenkomst</translation>
    </message>
    <message>
        <source>Remote Cert Type</source>
        <translation>Extern cert.type</translation>
    </message>
    <message>
        <source>Key File</source>
        <translation>Sleutelbestand</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>Sleutelrichting aanpassen</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>Sleutelrichting</translation>
    </message>
</context>
<context>
    <name>VpnVPNCSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Ongeldige gateway</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Opgeslagen</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Vragen</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Niet vereist</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Vereist</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Gebruikersnaam</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Pwd-opties</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Wachtwoord</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>Groepsnaam</translation>
    </message>
    <message>
        <source>Group Pwd</source>
        <translation>Groepswachtwoord</translation>
    </message>
    <message>
        <source>Use Hybrid Authentication</source>
        <translation>Hybride verificatie gebruiken</translation>
    </message>
    <message>
        <source>CA File</source>
        <translation>CA-bestand</translation>
    </message>
</context>
<context>
    <name>WiredPage</name>
    <message>
        <source>Plug in the network cable first</source>
        <translation>Sluit eerst de netwerkkabel aan</translation>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation>Bekabelde netwerkadapter</translation>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>Netwerkverbinding toevoegen</translation>
    </message>
    <message>
        <source>Select Settings</source>
        <translation>Instellingen selecteren</translation>
    </message>
</context>
<context>
    <name>WirelessPage</name>
    <message>
        <source>Wireless Network Adapter</source>
        <translation>Draadloze netwerkadapter</translation>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
    </message>
    <message>
        <source>Close Hotspot</source>
        <translation>Hotspot uitschakelen</translation>
    </message>
    <message>
        <source>Disable hotspot first if you want to connect to a wireless network</source>
        <translation>Schakel de hotspot uit om verbinding te kunnen maken met een draadloos netwerk</translation>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>Verbinden met verborgen netwerk</translation>
        <extra-contents_path>/network/Connect to hidden network</extra-contents_path>
        <extra-child_page>WirelessPage</extra-child_page>
    </message>
</context>
<context>
    <name>WirelessSection</name>
    <message>
        <source>WLAN</source>
        <translation>WLAN</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>Niet verbonden</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Vereist</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>MAC-adres van apparaat</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>MTU aanpassen</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
</context>
</TS>